# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import gettext_lazy as _
from django.core import validators

from .validators import validate_disposable_email
from .forms import DisposableEmailField as DisposableEmailFormField


class DisposableEmailField(models.EmailField):
    default_validators = [validators.validate_email, validate_disposable_email]
    description = _("Not a disposable email address")

    def formfield(self, **kwargs):
        # As with CharField, this will cause email validation to be performed
        # twice.
        defaults = {
            "form_class": DisposableEmailFormField,
        }
        defaults.update(kwargs)
        return super(DisposableEmailField, self).formfield(**defaults)



# -*- coding: utf-8 -*-

import re
from django.conf import settings
from django.utils.encoding import force_str
from django.core import validators
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _

from bdea.client import BDEAClient

from django.urls import get_callable


class DisposableEmailChecker(object):
    """
    Check if an email is from a disposable email service
    """

    message = _("Blocked email provider.")
    code = "invalid"
    whitelist = []

    def __init__(self, message=None, code=None, whitelist=None):
        if message is not None:
            self.message = message
        elif hasattr(settings, "BDEA_MESSAGE"):
            self.message = getattr(settings, "BDEA_MESSAGE")
        if code is not None:
            self.code = code
        if whitelist is not None:
            self.whitelist = whitelist

        self.emails = self._load_emails()
        self.BDEA_APIKEY = getattr(settings, "BDEA_APIKEY", None)
        self.BDEA_TIMEOUT = getattr(settings, "BDEA_TIMEOUT", 5)

    def __call__(self, value):
        value = force_str(value)

        # Catch invalid emails before we check if they're disposable
        try:
            validators.validate_email(value)
        except ValidationError:
            return

        user_part, domain_part = value.rsplit("@", 1)

        if domain_part not in self.whitelist:
            if self.BDEA_APIKEY:  # Validate using block-disposable-email.com
                client = BDEAClient(
                    self.BDEA_APIKEY, timeout=self.BDEA_TIMEOUT
                )
                response = client.get_domain_status(domain_part)

                if response.status() and response.is_disposable():
                    raise ValidationError(self.message, code=self.code)

            """
            This will run if we are not using BDEA, we're out of BDEA credits,
            there was an error contacting BDEA's servers or we did not get a
            hit on BDEA. Basically always check using local list as a backup
            """
            for email_group in self.chunk(self.emails, 20):
                regex = "(.*" + "$)|(.*".join(email_group) + "$)"
                if re.match(regex, value):
                    raise ValidationError(self.message, code=self.code)

    def _load_emails(self):
        loader = getattr(
            settings,
            "DEC_LOADER",
            "disposable_email_checker.emails.email_domain_loader",
        )
        return get_callable(loader)()

    def chunk(self, emails, n):
        return (emails[i : i + n] for i in range(0, len(emails), n))


validate_disposable_email = DisposableEmailChecker()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys

import disposable_email_checker

from setuptools import setup

version = disposable_email_checker.__version__

if sys.argv[-1] == "publish":
    os.system("python setup.py sdist upload")
    os.system("python setup.py bdist_wheel upload")
    sys.exit()

if sys.argv[-1] == "tag":
    print("Tagging the version on github:")
    os.system("git tag -a %s -m 'version %s'" % (version, version))
    os.system("git push --tags")
    sys.exit()

readme = open("README.md").read()

setup(
    name="django-disposable-email-checker",
    version=version,
    description="""Django package to detect ~890 domains used by disposable email services""",
    long_description=readme,
    long_description_content_type="text/markdown",
    author="Jason Held",
    author_email="jasonsheld@gmail.com",
    url="https://github.com/jheld/DisposableEmailChecker",
    packages=["disposable_email_checker",],
    include_package_data=True,
    install_requires=["block-disposable-email>=2.0.0",],
    license="BSD",
    zip_safe=False,
    keywords="DisposableEmailChecker",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
)



def email_domain_loader():
    return [
        "0-mail.com",
        "0815.ru",
        "0815.su",
        "0clickemail.com",
        "0sg.net",
        "0wnd.net",
        "0wnd.org",
        "10mail.org",
        "10minutemail.cf",
        "10minutemail.com",
        "10minutemail.de",
        "10minutemail.ga",
        "10minutemail.gq",
        "10minutemail.ml",
        "123-m.com",
        "12hourmail.com",
        "12minutemail.com",
        "1ce.us",
        "1chuan.com",
        "1mail.ml",
        "1pad.de",
        "1zhuan.com",
        "20mail.in",
        "20mail.it",
        "20minutemail.com",
        "21cn.com",
        "24hourmail.com",
        "2prong.com",
        "30minutemail.com",
        "30minutesmail.com",
        "3126.com",
        "33mail.com",
        "3d-painting.com",
        "3mail.ga",
        "4mail.cf",
        "4mail.ga",
        "4warding.com",
        "4warding.net",
        "4warding.org",
        "50e.info",
        "5mail.cf",
        "5mail.ga",
        "60minutemail.com",
        "675hosting.com",
        "675hosting.net",
        "675hosting.org",
        "6ip.us",
        "6mail.cf",
        "6mail.ga",
        "6mail.ml",
        "6paq.com",
        "6url.com",
        "75hosting.com",
        "75hosting.net",
        "75hosting.org",
        "7days-printing.com",
        "7mail.ga",
        "7mail.ml",
        "7tags.com",
        "8mail.cf",
        "8mail.ga",
        "8mail.ml",
        "99experts.com",
        "9mail.cf",
        "9ox.net",
        "BeefMilk.com",
        "DingBone.com",
        "FudgeRub.com",
        "LookUgly.com",
        "MailScrap.com",
        "SmellFear.com",
        "TempEmail.net",
        "a-bc.net",
        "a45.in",
        "abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijk.com",
        "abusemail.de",
        "abwesend.de",
        "abyssmail.com",
        "ac20mail.in",
        "acentri.com",
        "addcom.de",
        "advantimo.com",
        "afrobacon.com",
        "ag.us.to",
        "agedmail.com",
        "agnitumhost.net",
        "ahk.jp",
        "ajaxapp.net",
        "alivance.com",
        "alpenjodel.de",
        "alphafrau.de",
        "amail.com",
        "amilegit.com",
        "amiri.net",
        "amiriindustries.com",
        "amorki.pl",
        "anappthat.com",
        "ano-mail.net",
        "anonbox.net",
        "anonymail.dk",
        "anonymbox.com",
        "antichef.com",
        "antichef.net",
        "antispam.de",
        "antispam24.de",
        "appixie.com",
        "armyspy.com",
        "asdasd.nl",
        "autosfromus.com",
        "aver.com",
        "azmeil.tk",
        "baldmama.de",
        "baldpapa.de",
        "ballyfinance.com",
        "baxomale.ht.cx",
        "beddly.com",
        "beefmilk.com",
        "betriebsdirektor.de",
        "big1.us",
        "bigmir.net",
        "bigprofessor.so",
        "bigstring.com",
        "bin-wieder-da.de",
        "binkmail.com",
        "bio-muesli.info",
        "bio-muesli.net",
        "bladesmail.net",
        "bleib-bei-mir.de",
        "blockfilter.com",
        "blogmyway.org",
        "bluebottle.com",
        "bobmail.info",
        "bodhi.lawlita.com",
        "bofthew.com",
        "bonbon.net",
        "bootybay.de",
        "boun.cr",
        "bouncr.com",
        "boxformail.in",
        "boxtemp.com.br",
        "brefmail.com",
        "brennendesreich.de",
        "briefemail.com",
        "broadbandninja.com",
        "brokenvalve.com",
        "brokenvalve.org",
        "bsnow.net",
        "bspamfree.org",
        "bu.mintemail.com",
        "buerotiger.de",
        "buffemail.com",
        "bugmenot.com",
        "bumpymail.com",
        "bund.us",
        "bundes-li.ga",
        "burnthespam.info",
        "burstmail.info",
        "buy-24h.net.ru",
        "buyusedlibrarybooks.org",
        "c2.hu",
        "cachedot.net",
        "cashette.com",
        "casualdx.com",
        "cbair.com",
        "ce.mintemail.com",
        "cellurl.com",
        "center-mail.de",
        "centermail.at",
        "centermail.ch",
        "centermail.com",
        "centermail.de",
        "centermail.info",
        "centermail.net",
        "cghost.s-a-d.de",
        "chammy.info",
        "cheatmail.de",
        "chogmail.com",
        "choicemail1.com",
        "chong-mail.com",
        "chong-mail.net",
        "chong-mail.org",
        "chongsoft.org",
        "clixser.com",
        "cmail.com",
        "cmail.net",
        "cmail.org",
        "coldemail.info",
        "consumerriot.com",
        "cool.fr.nf",
        "coole-files.de",
        "correo.blogos.net",
        "cosmorph.com",
        "courriel.fr.nf",
        "courrieltemporaire.com",
        "crapmail.org",
        "crazespaces.pw",
        "crazymailing.com",
        "cubiclink.com",
        "curryworld.de",
        "cust.in",
        "cuvox.de",
        "cyber-matrix.com",
        "dacoolest.com",
        "daintly.com",
        "dandikmail.com",
        "dating4best.net",
        "dayrep.com",
        "dbunker.com",
        "dcemail.com",
        "deadaddress.com",
        "deadchildren.org",
        "deadfake.cf",
        "deadfake.ga",
        "deadfake.ml",
        "deadfake.tk",
        "deadspam.com",
        "deagot.com",
        "dealja.com",
        "despam.it",
        "despammed.com",
        "devnullmail.com",
        "dfgh.net",
        "dharmatel.net",
        "die-besten-bilder.de",
        "die-genossen.de",
        "die-optimisten.de",
        "die-optimisten.net",
        "dieMailbox.de",
        "digital-filestore.de",
        "digitalsanctuary.com",
        "dingbone.com",
        "directbox.com",
        "discard.cf",
        "discard.email",
        "discard.ga",
        "discard.gq",
        "discard.ml",
        "discard.tk",
        "discardmail.*",
        "discardmail.com",
        "discardmail.de",
        "discartmail.com",
        "disposable-email.ml",
        "disposable.cf",
        "disposable.ga",
        "disposable.ml",
        "disposableaddress.com",
        "disposableemailaddresses.com",
        "disposableemailaddresses.emailmiser.com",
        "disposableinbox.com",
        "dispose.it",
        "disposeamail.com",
        "disposemail.com",
        "dispostable.com",
        "divermail.com",
        "dm.w3internet.co.uk",
        "example.com",
        "docmail.cz",
        "dodgeit.com",
        "dodgit.com",
        "dodgit.org",
        "dogit.com",
        "doiea.com",
        "domozmail.com",
        "donemail.ru",
        "dontreg.com",
        "dontsendmespam.de",
        "dontsentmespam.de",
        "dotmsg.com",
        "download-privat.de",
        "drdrb.com",
        "drdrb.net",
        "droplar.com",
        "dropmail.me",
        "duam.net",
        "dudmail.com",
        "dump-email.info",
        "dumpandjunk.com",
        "dumpmail.com",
        "dumpmail.de",
        "dumpyemail.com",
        "duskmail.com",
        "dyndns.org",
        "e-mail.com",
        "e-mail.org",
        "e4ward.com",
        "easytrashmail.com",
        "ee2.pl",
        "eelmail.com",
        "einrot.com",
        "einrot.de",
        "eintagsmail.de",
        "email-fake.cf",
        "email-fake.ga",
        "email-fake.gq",
        "email-fake.ml",
        "email-fake.tk",
        "email.org",
        "email4u.info",
        "email60.com",
        "emailage.cf",
        "emailage.ga",
        "emailage.gq",
        "emailage.ml",
        "emailage.tk",
        "emaildienst.de",
        "emailgo.de",
        "emailias.com",
        "emailigo.de",
        "emailinfive.com",
        "emailisvalid.com",
        "emaillime.com",
        "emailmiser.com",
        "emailproxsy.com",
        "emails.ga",
        "emailsensei.com",
        "emailspam.cf",
        "emailspam.ga",
        "emailspam.gq",
        "emailspam.ml",
        "emailspam.tk",
        "emailtaxi.de",
        "emailtemporanea.net",
        "emailtemporar.ro",
        "emailtemporario.com.br",
        "emailthe.net",
        "emailtmp.com",
        "emailto.de",
        "emailwarden.com",
        "emailx.at.hm",
        "emailxfer.com",
        "emailz.cf",
        "emailz.ga",
        "emailz.gq",
        "emailz.ml",
        "emeil.in",
        "emeil.ir",
        "emil.com",
        "emkei.cf",
        "emkei.ga",
        "emkei.gq",
        "emkei.ml",
        "emkei.tk",
        "emz.net",
        "enterto.com",
        "ephemail.net",
        "etranquil.com",
        "etranquil.net",
        "etranquil.org",
        "evopo.com",
        "example.com",
        "explodemail.com",
        "eyepaste.com",
        "facebook-email.cf",
        "facebook-email.ga",
        "facebook-email.ml",
        "facebookmail.gq",
        "facebookmail.ml",
        "fahr-zur-hoelle.org",
        "fake-mail.cf",
        "fake-mail.ga",
        "fake-mail.ml",
        "fakeinbox.cf",
        "fakeinbox.com",
        "fakeinbox.ga",
        "fakeinbox.ml",
        "fakeinbox.tk",
        "fakeinformation.com",
        "fakemail.fr",
        "fakemailgenerator.com",
        "fakemailz.com",
        "falseaddress.com",
        "fammix.com",
        "fansworldwide.de",
        "fantasymail.de",
        "farifluset.mailexpire.com",
        "fastacura.com",
        "fastchevy.com",
        "fastchrysler.com",
        "fastkawasaki.com",
        "fastmazda.com",
        "fastmitsubishi.com",
        "fastnissan.com",
        "fastsubaru.com",
        "fastsuzuki.com",
        "fasttoyota.com",
        "fastyamaha.com",
        "fatflap.com",
        "fdfdsfds.com",
        "feinripptraeger.de",
        "fettabernett.de",
        "fightallspam.com",
        "fiifke.de",
        "filzmail.com",
        "fishfuse.com",
        "fixmail.tk",
        "fizmail.com",
        "fleckens.hu",
        "flurred.com",
        "flyspam.com",
        "footard.com",
        "forgetmail.com",
        "fornow.eu",
        "fr33mail.info",
        "frapmail.com",
        "free-email.cf",
        "free-email.ga",
        "freemail.ms",
        "freemails.cf",
        "freemails.ga",
        "freemails.ml",
        "freemeilaadressforall.net",
        "freudenkinder.de",
        "freundin.ru",
        "friendlymail.co.uk",
        "fromru.com",
        "front14.org",
        "fuckingduh.com",
        "fudgerub.com",
        "fux0ringduh.com",
        "garliclife.com",
        "gawab.com",
        "gelitik.in",
        "gentlemansclub.de",
        "get-mail.cf",
        "get-mail.ga",
        "get-mail.ml",
        "get-mail.tk",
        "get1mail.com",
        "get2mail.fr",
        "getairmail.cf",
        "getairmail.com",
        "getairmail.ga",
        "getairmail.gq",
        "getairmail.ml",
        "getairmail.tk",
        "getmails.eu",
        "getonemail.com",
        "getonemail.net",
        "ghosttexter.de",
        "girlsundertheinfluence.com",
        "gishpuppy.com",
        "goemailgo.com",
        "gold-profits.info",
        "goldtoolbox.com",
        "golfilla.info",
        "gorillaswithdirtyarmpits.com",
        "gotmail.com",
        "gotmail.net",
        "gotmail.org",
        "gotti.otherinbox.com",
        "gowikibooks.com",
        "gowikicampus.com",
        "gowikicars.com",
        "gowikifilms.com",
        "gowikigames.com",
        "gowikimusic.com",
        "gowikinetwork.com",
        "gowikitravel.com",
        "gowikitv.com",
        "grandmamail.com",
        "grandmasmail.com",
        "great-host.in",
        "greensloth.com",
        "grr.la",
        "gsrv.co.uk",
        "guerillamail.biz",
        "guerillamail.com",
        "guerillamail.net",
        "guerillamail.org",
        "guerrillamail.biz",
        "guerrillamail.com",
        "guerrillamail.de",
        "guerrillamail.info",
        "guerrillamail.net",
        "guerrillamail.org",
        "guerrillamailblock.com",
        "gustr.com",
        "h.mintemail.com",
        "h8s.org",
        "hab-verschlafen.de",
        "habmalnefrage.de",
        "hacccc.com",
        "haltospam.com",
        "harakirimail.com",
        "hartbot.de",
        "hatespam.org",
        "hellodream.mobi",
        "herp.in",
        "herr-der-mails.de",
        "hidemail.de",
        "hidzz.com",
        "hmamail.com",
        "hochsitze.com",
        "home.de",
        "hopemail.biz",
        "hot-mail.cf",
        "hot-mail.ga",
        "hot-mail.gq",
        "hot-mail.ml",
        "hot-mail.tk",
        "hotpop.com",
        "hulapla.de",
        "humn.ws.gy",
        "hush.com",
        "hushmail.com",
        "ich-bin-verrueckt-nach-dir.de",
        "ich-will-net.de",
        "ieatspam.eu",
        "ieatspam.info",
        "ieh-mail.de",
        "ihateyoualot.info",
        "iheartspam.org",
        "ikbenspamvrij.nl",
        "imails.info",
        "imgof.com",
        "imstations.com",
        "inbax.tk",
        "inbox.si",
        "inbox2.info",
        "inboxalias.com",
        "inboxclean.com",
        "inboxclean.org",
        "inboxproxy.com",
        "incognitomail.com",
        "incognitomail.net",
        "incognitomail.org",
        "inerted.com",
        "inmail24.com",
        "insorg-mail.info",
        "instant-mail.de",
        "instantemailaddress.com",
        "ipoo.org",
        "irish2me.com",
        "iroid.com",
        "ist-allein.info",
        "ist-einmalig.de",
        "ist-ganz-allein.de",
        "ist-willig.de",
        "iwi.net",
        "izmail.net",
        "jetable.com",
        "jetable.de",
        "jetable.fr.nf",
        "jetable.net",
        "jetable.org",
        "jetfix.ee",
        "jetzt-bin-ich-dran.com",
        "jn-club.de",
        "jnxjn.com",
        "jobbikszimpatizans.hu",
        "jourrapide.com",
        "jsrsolutions.com",
        "junk1e.com",
        "junkmail.com",
        "junkmail.ga",
        "junkmail.gq",
        "kaffeeschluerfer.com",
        "kaffeeschluerfer.de",
        "kasmail.com",
        "kaspop.com",
        "keepmymail.com",
        "killmail.com",
        "killmail.net",
        "kimsdisk.com",
        "kinglibrary.net",
        "kingsq.ga",
        "kir.ch.tc",
        "klassmaster.com",
        "klassmaster.net",
        "klzlk.com",
        "kommespaeter.de",
        "kook.ml",
        "koszmail.pl",
        "krim.ws",
        "kuh.mu",
        "kulturbetrieb.info",
        "kurzepost.de",
        "l33r.eu",
        "labetteraverouge.at",
        "lackmail.net",
        "lags.us",
        "landmail.co",
        "lass-es-geschehen.de",
        "lastmail.co",
        "lastmail.com",
        "lazyinbox.com",
        "letthemeatspam.com",
        "lhsdv.com",
        "liebt-dich.info",
        "lifebyfood.com",
        "link2mail.net",
        "listomail.com",
        "litedrop.com",
        "loadby.us",
        "login-email.cf",
        "login-email.ga",
        "login-email.ml",
        "login-email.tk",
        "lol.ovpn.to",
        "lookugly.com",
        "lopl.co.cc",
        "lortemail.dk",
        "lovemeleaveme.com",
        "loveyouforever.de",
        "lr7.us",
        "lr78.com",
        "lroid.com",
        "luv2.us",
        "m4ilweb.info",
        "maboard.com",
        "maennerversteherin.com",
        "maennerversteherin.de",
        "mail-filter.com",
        "mail-temporaire.fr",
        "mail.by",
        "mail.htl22.at",
        "mail.mezimages.net",
        "mail.misterpinball.de",
        "mail.svenz.eu",
        "mail114.net",
        "mail15.com",
        "mail2rss.org",
        "mail333.com",
        "mail4days.com",
        "mail4trash.com",
        "mail4u.info",
        "mailbidon.com",
        "mailblocks.com",
        "mailbucket.org",
        "mailcat.biz",
        "mailcatch.*",
        "mailcatch.com",
        "maildrop.cc",
        "maildrop.cf",
        "maildrop.ga",
        "maildrop.gq",
        "maildrop.ml",
        "maildx.com",
        "maileater.com",
        "mailexpire.com",
        "mailfa.tk",
        "mailforspam.com",
        "mailfree.ga",
        "mailfree.gq",
        "mailfree.ml",
        "mailfreeonline.com",
        "mailfs.com",
        "mailguard.me",
        "mailimate.com",
        "mailin8r.com",
        "mailinater.com",
        "mailinator.com",
        "mailinator.gq",
        "mailinator.net",
        "mailinator.org",
        "mailinator.us",
        "mailinator2.com",
        "mailinblack.com",
        "mailincubator.com",
        "mailismagic.com",
        "mailjunk.cf",
        "mailjunk.ga",
        "mailjunk.gq",
        "mailjunk.ml",
        "mailjunk.tk",
        "mailmate.com",
        "mailme.gq",
        "mailme.ir",
        "mailme.lv",
        "mailme24.com",
        "mailmetrash.com",
        "mailmoat.com",
        "mailnator.com",
        "mailnesia.com",
        "mailnull.com",
        "mailpick.biz",
        "mailproxsy.com",
        "mailquack.com",
        "mailrock.biz",
        "mailsac.com",
        "mailscrap.com",
        "mailseal.de",
        "mailshell.com",
        "mailsiphon.com",
        "mailslapping.com",
        "mailslite.com",
        "mailtemp.info",
        "mailtothis.com",
        "mailtrash.net",
        "mailueberfall.de",
        "mailzilla.com",
        "mailzilla.org",
        "mailzilla.orgmbx.cc",
        "makemetheking.com",
        "mamber.net",
        "manifestgenerator.com",
        "manybrain.com",
        "mbx.cc",
        "mciek.com",
        "mega.zik.dj",
        "meine-dateien.info",
        "meine-diashow.de",
        "meine-fotos.info",
        "meine-urlaubsfotos.de",
        "meinspamschutz.de",
        "meltmail.com",
        "messagebeamer.de",
        "metaping.com",
        "mezimages.net",
        "mfsa.ru",
        "mierdamail.com",
        "migumail.com",
        "mintemail.com",
        "mjukglass.nu",
        "mns.ru",
        "moakt.com",
        "mobi.web.id",
        "mobileninja.co.uk",
        "moburl.com",
        "mohmal.com",
        "moncourrier.fr.nf",
        "monemail.fr.nf",
        "monmail.fr.nf",
        "monumentmail.com",
        "ms9.mailslite.com",
        "msa.minsmail.com",
        "msh.mailslite.com",
        "mt2009.com",
        "mt2014.com",
        "mufmail.com",
        "muskelshirt.de",
        "mx0.wwwnew.eu",
        "my-mail.ch",
        "my10minutemail.com",
        "myadult.info",
        "mycleaninbox.net",
        "myemailboxy.com",
        "mymail-in.net",
        "mymailoasis.com",
        "mynetstore.de",
        "mypacks.net",
        "mypartyclip.de",
        "myphantomemail.com",
        "myspaceinc.com",
        "myspaceinc.net",
        "myspaceinc.org",
        "myspacepimpedup.com",
        "myspamless.com",
        "mytemp.email",
        "mytempemail.com",
        "mytop-in.net",
        "mytrashmail.com",
        "mytrashmail.compookmail.com",
        "neomailbox.com",
        "nepwk.com",
        "nervmich.net",
        "nervtmich.net",
        "netmails.com",
        "netmails.net",
        "netterchef.de",
        "netzidiot.de",
        "neue-dateien.de",
        "neverbox.com",
        "nice-4u.com",
        "nmail.cf",
        "no-spam.ws",
        "nobulk.com",
        "noclickemail.com",
        "nogmailspam.info",
        "nomail.xl.cx",
        "nomail2me.com",
        "nomorespamemails.com",
        "nonspam.eu",
        "nonspammer.de",
        "noref.in",
        "nospam.wins.com.br",
        "nospam.ze.tc",
        "nospam4.us",
        "nospamfor.us",
        "nospammail.net",
        "nospamthanks.info",
        "notmailinator.com",
        "notsharingmy.info",
        "nowhere.org",
        "nowmymail.com",
        "ntlhelp.net",
        "nullbox.info",
        "nur-fuer-spam.de",
        "nurfuerspam.de",
        "nus.edu.sg",
        "nwldx.com",
        "nybella.com",
        "objectmail.com",
        "obobbo.com",
        "odaymail.com",
        "office-dateien.de",
        "oikrach.com",
        "one-time.email",
        "oneoffemail.com",
        "oneoffmail.com",
        "onewaymail.com",
        "online.ms",
        "oopi.org",
        "opayq.com",
        "orangatango.com",
        "ordinaryamerican.net",
        "otherinbox.com",
        "ourklips.com",
        "outlawspam.com",
        "ovpn.to",
        "owlpic.com",
        "pancakemail.com",
        "paplease.com",
        "partybombe.de",
        "partyheld.de",
        "pcusers.otherinbox.com",
        "pepbot.com",
        "pfui.ru",
        "phreaker.net",
        "pimpedupmyspace.com",
        "pisem.net",
        "pjjkp.com",
        "pleasedontsendmespam.de",
        "plexolan.de",
        "poczta.onet.pl",
        "politikerclub.de",
        "polizisten-duzer.de",
        "poofy.org",
        "pookmail.com",
        "pornobilder-mal-gratis.com",
        "portsaid.cc",
        "postacin.com",
        "postfach.cc",
        "privacy.net",
        "privy-mail.com",
        "privymail.de",
        "proxymail.eu",
        "prtnx.com",
        "prtz.eu",
        "prydirect.info",
        "pryworld.info",
        "public-files.de",
        "punkass.com",
        "put2.net",
        "putthisinyourspamdatabase.com",
        "pwrby.com",
        "qasti.com",
        "qisdo.com",
        "qisoa.com",
        "qq.com",
        "quantentunnel.de",
        "quickinbox.com",
        "quickmail.nl",
        "qv7.info",
        "radiku.ye.vc",
        "ralib.com",
        "raubtierbaendiger.de",
        "rcpt.at",
        "reallymymail.com",
        "receiveee.chickenkiller.com",
        "receiveee.com",
        "recode.me",
        "reconmail.com",
        "record.me",
        "recursor.net",
        "recyclemail.dk",
        "regbypass.com",
        "regbypass.comsafe-mail.net",
        "rejectmail.com",
        "remail.cf",
        "remail.ga",
        "rhyta.com",
        "rk9.chickenkiller.com",
        "rklips.com",
        "rmqkr.net",
        "rootprompt.org",
        "royal.net",
        "rppkn.com",
        "rtrtr.com",
        "ruffrey.com",
        "s0ny.net",
        "saeuferleber.de",
        "safe-mail.net",
        "safersignup.de",
        "safetymail.info",
        "safetypost.de",
        "sags-per-mail.de",
        "sandelf.de",
        "satka.net",
        "saynotospams.com",
        "scarden.com",
        "scatmail.com",
        "schafmail.de",
        "schmusemail.de",
        "schreib-doch-mal-wieder.de",
        "selfdestructingmail.com",
        "selfdestructingmail.org",
        "sendspamhere.com",
        "senseless-entertainment.com",
        "shared-files.de",
        "sharedmailbox.org",
        "sharklasers.com",
        "shieldedmail.com",
        "shiftmail.com",
        "shinedyoureyes.com",
        "shitmail.me",
        "shitmail.org",
        "shitware.nl",
        "shortmail.net",
        "showslow.de",
        "sibmail.com",
        "sinnlos-mail.de",
        "siria.cc",
        "siteposter.net",
        "skeefmail.com",
        "skeefmail.net",
        "slaskpost.se",
        "slave-auctions.net",
        "slopsbox.com",
        "slushmail.com",
        "smashmail.de",
        "smellfear.com",
        "smellrear.com",
        "sms.at",
        "snakemail.com",
        "sneakemail.com",
        "snkmail.com",
        "sofimail.com",
        "sofort-mail.de",
        "sofortmail.de",
        "softpls.asia",
        "sogetthis.com",
        "sohu.com",
        "soisz.com",
        "solvemail.info",
        "sonnenkinder.org",
        "soodomail.com",
        "soodonims.com",
        "spam-be-gone.com",
        "spam.la",
        "spam.su",
        "spam4.me",
        "spamavert.com",
        "spambob.com",
        "spambob.net",
        "spambob.org",
        "spambog.*",
        "spambog.com",
        "spambog.de",
        "spambog.net",
        "spambog.ru",
        "spambooger.com",
        "spambox.info",
        "spambox.irishspringrealty.com",
        "spambox.us",
        "spamcannon.com",
        "spamcannon.net",
        "spamcero.com",
        "spamcon.org",
        "spamcorptastic.com",
        "spamcowboy.com",
        "spamcowboy.net",
        "spamcowboy.org",
        "spamday.com",
        "spamdecoy.net",
        "spameater.com",
        "spameater.org",
        "spamex.com",
        "spamfighter.cf",
        "spamfighter.ga",
        "spamfighter.gq",
        "spamfighter.ml",
        "spamfighter.tk",
        "spamfree.eu",
        "spamfree24.com",
        "spamfree24.de",
        "spamfree24.eu",
        "spamfree24.info",
        "spamfree24.net",
        "spamfree24.org",
        "spamgoes.in",
        "spamgourmet.com",
        "spamgourmet.net",
        "spamgourmet.org",
        "spamgrube.net",
        "spamherelots.com",
        "spamhereplease.com",
        "spamhole.com",
        "spamify.com",
        "spaminator.de",
        "spamkill.info",
        "spaml.com",
        "spaml.de",
        "spammote.com",
        "spammotel.com",
        "spammuffel.de",
        "spamobox.com",
        "spamoff.de",
        "spamreturn.com",
        "spamsalad.in",
        "spamslicer.com",
        "spamspot.com",
        "spamstack.net",
        "spamthis.co.uk",
        "spamthisplease.com",
        "spamtrail.com",
        "spamtroll.net",
        "speed.1s.fr",
        "sperke.net",
        "spikio.com",
        "spoofmail.de",
        "squizzy.de",
        "sriaus.com",
        "ssoia.com",
        "startkeys.com",
        "stinkefinger.net",
        "stop-my-spam.cf",
        "stop-my-spam.com",
        "stop-my-spam.ga",
        "stop-my-spam.ml",
        "stop-my-spam.tk",
        "streber24.de",
        "streetwisemail.com",
        "stuffmail.de",
        "super-auswahl.de",
        "supergreatmail.com",
        "supermailer.jp",
        "superrito.com",
        "superstachel.de",
        "suremail.info",
        "svk.jp",
        "sweetville.net",
        "sweetxxx.de",
        "tafmail.com",
        "tagesmail.eu",
        "tagyourself.com",
        "talkinator.com",
        "tapchicuoihoi.com",
        "teewars.org",
        "teleworm.com",
        "teleworm.us",
        "temp-mail.com",
        "temp-mail.org",
        "temp.emeraldwebmail.com",
        "temp.headstrong.de",
        "tempail.com",
        "tempalias.com",
        "tempe-mail.com",
        "tempemail.biz",
        "tempemail.co.za",
        "tempemail.com",
        "tempemail.net",
        "tempinbox.co.uk",
        "tempinbox.com",
        "tempmail.it",
        "tempmail2.com",
        "tempmaildemo.com",
        "tempmailer.com",
        "tempomail.fr",
        "temporarily.de",
        "temporarioemail.com.br",
        "temporaryemail.net",
        "temporaryemail.us",
        "temporaryforwarding.com",
        "temporaryinbox.com",
        "tempsky.com",
        "tempthe.net",
        "tempymail.com",
        "terminverpennt.de",
        "test.com",
        "test.de",
        "thanksnospam.info",
        "thankyou2010.com",
        "thecloudindex.com",
        "thepryam.info",
        "thisisnotmyrealemail.com",
        "throam.com",
        "throwawayemailaddress.com",
        "throwawaymail.com",
        "tilien.com",
        "tittbit.in",
        "tmail.ws",
        "tmailinator.com",
        "toiea.com",
        "toomail.biz",
        "topmail-files.de",
        "tortenboxer.de",
        "totalmail.de",
        "tradermail.info",
        "trash-amil.com",
        "trash-mail.at",
        "trash-mail.cf",
        "trash-mail.com",
        "trash-mail.de",
        "trash-mail.ga",
        "trash-mail.gq",
        "trash-mail.ml",
        "trash-mail.tk",
        "trash2009.com",
        "trash2010.com",
        "trash2011.com",
        "trashbox.eu",
        "trashdevil.com",
        "trashdevil.de",
        "trashemail.de",
        "trashmail.at",
        "trashmail.com",
        "trashmail.de",
        "trashmail.me",
        "trashmail.net",
        "trashmail.org",
        "trashmail.ws",
        "trashmailer.com",
        "trashymail.com",
        "trashymail.net",
        "trayna.com",
        "trbvm.com",
        "trickmail.net",
        "trillianpro.com",
        "trimix.cn",
        "tryalert.com",
        "turboprinz.de",
        "turboprinzessin.de",
        "turual.com",
        "twinmail.de",
        "twoweirdtricks.com",
        "tyldd.com",
        "ubismail.net",
        "uggsrock.com",
        "uk2.net",
        "ukr.net",
        "umail.net",
        "unmail.ru",
        "unterderbruecke.de",
        "upliftnow.com",
        "uplipht.com",
        "uroid.com",
        "username.e4ward.com",
        "valemail.net",
        "venompen.com",
        "verlass-mich-nicht.de",
        "veryrealemail.com",
        "vidchart.com",
        "viditag.com",
        "viewcastmedia.com",
        "viewcastmedia.net",
        "viewcastmedia.org",
        "vinbazar.com",
        "vollbio.de",
        "volloeko.de",
        "vomoto.com",
        "vorsicht-bissig.de",
        "vorsicht-scharf.de",
        "vubby.com",
        "walala.org",
        "walkmail.net",
        "war-im-urlaub.de",
        "wbb3.de",
        "webemail.me",
        "webm4il.info",
        "webmail4u.eu",
        "webuser.in",
        "wee.my",
        "weg-werf-email.de",
        "wegwerf-email-addressen.de",
        "wegwerf-emails.de",
        "wegwerfadresse.de",
        "wegwerfemail.com",
        "wegwerfemail.de",
        "wegwerfmail.de",
        "wegwerfmail.info",
        "wegwerfmail.net",
        "wegwerfmail.org",
        "wegwerpmailadres.nl",
        "weibsvolk.de",
        "weibsvolk.org",
        "weinenvorglueck.de",
        "wetrainbayarea.com",
        "wetrainbayarea.org",
        "wh4f.org",
        "whatiaas.com",
        "whatpaas.com",
        "whatsaas.com",
        "whopy.com",
        "whtjddn.33mail.com",
        "whyspam.me",
        "wickmail.net",
        "wilemail.com",
        "will-hier-weg.de",
        "willhackforfood.biz",
        "willselfdestruct.com",
        "winemaven.info",
        "wir-haben-nachwuchs.de",
        "wir-sind-cool.org",
        "wirsindcool.de",
        "wmail.cf",
        "wolke7.net",
        "wollan.info",
        "women-at-work.org",
        "wormseo.cn",
        "wronghead.com",
        "wuzup.net",
        "wuzupmail.net",
        "www.e4ward.com",
        "www.gishpuppy.com",
        "www.mailinator.com",
        "wwwnew.eu",
        "xagloo.com",
        "xemaps.com",
        "xents.com",
        "xmail.com",
        "xmaily.com",
        "xoxox.cc",
        "xoxy.net",
        "xsecurity.org",
        "xyzfree.net",
        "yapped.net",
        "yeah.net",
        "yep.it",
        "yert.ye.vc",
        "yesey.net",
        "yogamaven.com",
        "yomail.info",
        "yopmail.com",
        "yopmail.fr",
        "yopmail.gq",
        "yopmail.net",
        "yopweb.com",
        "youmail.ga",
        "youmailr.com",
        "ypmail.webarnak.fr.eu.org",
        "ystea.org",
        "yuurok.com",
        "yzbid.com",
        "za.com",
        "zehnminutenmail.de",
        "zetmail.com",
        "zippymail.info",
        "zoaxe.com",
        "zoemail.com",
        "zoemail.net",
        "zoemail.org",
        "zomg.info",
        "zweb.in",
        "zxcv.com",
        "zxcvbnm.com",
        "zzz.com",
    ]



# -*- coding: utf-8 -*-

from django import forms
from django.core import validators
from .validators import validate_disposable_email


class DisposableEmailField(forms.EmailField):
    default_validators = [validators.validate_email, validate_disposable_email]
